# Generated by Django 3.1.5 on 2022-01-20 23:44

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('django_postalcodes_mexico', '0003_auto_20210115_2331'),
    ]

    operations = [
        migrations.AlterField(
            model_name='postalcode',
            name='D_mnpio',
            field=models.CharField(max_length=128, verbose_name='Nombre Municipio (INEGI, Marzo 2013)'),
        ),
        migrations.AlterField(
            model_name='postalcode',
            name='c_cve_ciudad',
            field=models.CharField(blank=True, max_length=2, null=True, verbose_name='Clave Ciudad (Catálogo SEPOMEX)'),
        ),
        migrations.AlterField(
            model_name='postalcode',
            name='c_estado',
            field=models.CharField(choices=[('26', 'Sonora'), ('10', 'Durango'), ('03', 'Baja California Sur'), ('04', 'Campeche'), ('16', 'Michoacán de Ocampo'), ('31', 'Yucatán'), ('19', 'Nuevo León'), ('12', 'Guerrero'), ('11', 'Guanajuato'), ('25', 'Sinaloa'), ('15', 'Ciudad de México'), ('29', 'Tlaxcala'), ('13', 'Hidalgo'), ('08', 'Chihuahua'), ('24', 'San Luis Potosí'), ('27', 'Tabasco'), ('23', 'Quintana Roo'), ('28', 'Tamaulipas'), ('14', 'Jalisco'), ('05', 'Coahuila de Zaragoza'), ('09', 'Ciudad de México'), ('21', 'Puebla'), ('06', 'Colima'), ('02', 'Baja California'), ('32', 'Zacatecas'), ('01', 'Aguascalientes'), ('22', 'Querétaro'), ('30', 'Veracruz de Ignacio de la Llave'), ('20', 'Oaxaca'), ('17', 'Morelos'), ('18', 'Nayarit'), ('07', 'Chiapas')], max_length=2, verbose_name='Clave Entidad (INEGI, Marzo 2013)'),
        ),
        migrations.AlterField(
            model_name='postalcode',
            name='c_mnpio',
            field=models.CharField(max_length=3, verbose_name='Clave Municipio (INEGI, Marzo 2013)'),
        ),
        migrations.AlterField(
            model_name='postalcode',
            name='c_oficina',
            field=models.CharField(max_length=5, verbose_name='Código Postal de la Administración Postal que reparte al asentamiento'),
        ),
        migrations.AlterField(
            model_name='postalcode',
            name='c_tipo_asenta',
            field=models.CharField(choices=[('32', 'Villa'), ('37', 'Zona industrial'), ('27', 'Poblado comunal'), ('20', 'Finca'), ('09', 'Colonia'), ('38', 'Ampliación'), ('10', 'Condominio'), ('34', 'Zona federal'), ('18', 'Exhacienda'), ('30', 'Residencial'), ('02', 'Barrio'), ('47', 'Zona militar'), ('12', 'Conjunto habitacional'), ('46', 'Zona naval'), ('23', 'Granja'), ('40', 'Puerto'), ('01', 'Aeropuerto'), ('15', 'Ejido'), ('04', 'Campamento'), ('45', 'Paraje'), ('29', 'Ranchería'), ('31', 'Unidad habitacional'), ('24', 'Hacienda'), ('28', 'Pueblo'), ('11', 'Congregación'), ('33', 'Zona comercial'), ('22', 'Gran usuario'), ('16', 'Estación'), ('26', 'Parque industrial'), ('48', 'Rancho'), ('21', 'Fraccionamiento'), ('17', 'Equipamiento')], max_length=2, verbose_name='Clave Tipo de asentamiento (Catálogo SEPOMEX)'),
        ),
        migrations.AlterField(
            model_name='postalcode',
            name='d_CP',
            field=models.CharField(blank=True, max_length=128, null=True, verbose_name='Código Postal de la Administración Postal que reparte al asentamiento'),
        ),
        migrations.AlterField(
            model_name='postalcode',
            name='d_asenta',
            field=models.CharField(max_length=128, verbose_name='Nombre asentamiento'),
        ),
        migrations.AlterField(
            model_name='postalcode',
            name='d_ciudad',
            field=models.CharField(blank=True, max_length=128, null=True, verbose_name='Nombre Ciudad (Catálogo SEPOMEX)'),
        ),
        migrations.AlterField(
            model_name='postalcode',
            name='d_codigo',
            field=models.CharField(max_length=5, verbose_name='Código Postal asentamiento'),
        ),
        migrations.AlterField(
            model_name='postalcode',
            name='d_zona',
            field=models.CharField(choices=[('Urbano', 'Urbano'), ('Rural', 'Rural'), ('Semiurbano', 'Semiurbano')], max_length=10, verbose_name='Zona en la que se ubica el asentamiento (Urbano/Rural)'),
        ),
        migrations.AlterField(
            model_name='postalcode',
            name='id_asenta_cpcons',
            field=models.CharField(max_length=4, verbose_name='Identificador único del asentamiento (nivel municipal)'),
        ),
    ]
