# Generated by Django 3.1.5 on 2021-01-15 21:49

from django.db import migrations, models
import django.utils.timezone
import model_utils.fields


class Migration(migrations.Migration):

    initial = True

    dependencies = [
    ]

    operations = [
        migrations.CreateModel(
            name='PostalCode',
            fields=[
                ('id', models.AutoField(auto_created=True, primary_key=True, serialize=False, verbose_name='ID')),
                ('created', model_utils.fields.AutoCreatedField(default=django.utils.timezone.now, editable=False, verbose_name='created')),
                ('modified', model_utils.fields.AutoLastModifiedField(default=django.utils.timezone.now, editable=False, verbose_name='modified')),
                ('d_codigo', models.CharField(max_length=5)),
                ('d_asenta', models.CharField(max_length=128)),
                ('D_mnpio', models.CharField(max_length=128)),
                ('d_ciudad', models.CharField(blank=True, max_length=128, null=True)),
                ('c_estado', models.CharField(choices=[('26', 'Sonora'), ('10', 'Durango'), ('03', 'Baja California Sur'), ('04', 'Campeche'), ('16', 'Michoacán de Ocampo'), ('31', 'Yucatán'), ('19', 'Nuevo León'), ('12', 'Guerrero'), ('11', 'Guanajuato'), ('25', 'Sinaloa'), ('15', 'México'), ('29', 'Tlaxcala'), ('13', 'Hidalgo'), ('08', 'Chihuahua'), ('24', 'San Luis Potosí'), ('27', 'Tabasco'), ('23', 'Quintana Roo'), ('28', 'Tamaulipas'), ('14', 'Jalisco'), ('05', 'Coahuila de Zaragoza'), ('09', 'Ciudad de México'), ('21', 'Puebla'), ('06', 'Colima'), ('02', 'Baja California'), ('32', 'Zacatecas'), ('01', 'Aguascalientes'), ('22', 'Querétaro'), ('30', 'Veracruz de Ignacio de la Llave'), ('20', 'Oaxaca'), ('17', 'Morelos'), ('18', 'Nayarit'), ('07', 'Chiapas')], max_length=2)),
                ('c_oficina', models.CharField(max_length=5)),
                ('c_CP', models.CharField(blank=True, max_length=128, null=True)),
                ('c_tipo_asenta', models.CharField(choices=[('32', 'Villa'), ('37', 'Zona industrial'), ('27', 'Poblado comunal'), ('20', 'Finca'), ('09', 'Colonia'), ('38', 'Ampliación'), ('10', 'Condominio'), ('34', 'Zona federal'), ('18', 'Exhacienda'), ('30', 'Residencial'), ('02', 'Barrio'), ('47', 'Zona militar'), ('12', 'Conjunto habitacional'), ('46', 'Zona naval'), ('23', 'Granja'), ('40', 'Puerto'), ('01', 'Aeropuerto'), ('15', 'Ejido'), ('04', 'Campamento'), ('45', 'Paraje'), ('29', 'Ranchería'), ('31', 'Unidad habitacional'), ('24', 'Hacienda'), ('28', 'Pueblo'), ('11', 'Congregación'), ('33', 'Zona comercial'), ('22', 'Gran usuario'), ('16', 'Estación'), ('26', 'Parque industrial'), ('48', 'Rancho'), ('21', 'Fraccionamiento'), ('17', 'Equipamiento')], max_length=2)),
                ('c_mnpio', models.CharField(max_length=3)),
                ('id_asenta_cpcons', models.CharField(max_length=4)),
                ('d_zona', models.CharField(choices=[('UR', 'Urbano'), ('RU', 'Rural'), ('SE', 'Semiurbano')], max_length=2)),
                ('c_cve_ciudad', models.CharField(blank=True, max_length=2, null=True)),
            ],
            options={
                'abstract': False,
            },
        ),
    ]
